/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.client.dataobject;

import de.bsvrz.pua.prot.util.attributes.TempAttributeDescription;

/**
 * Fasst Informationen über eine Spalte mit einem temporären Attribut zusammen.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class TempAttributeColumn extends Column {

	private static final long serialVersionUID = -1361517570199737522L;

	private final long _pseudoObjectIndex;

	/** @param tad Attributbeschreibung auf der die Spalte basiert. */
	public TempAttributeColumn(TempAttributeDescription tad) {
		super(ColumnType.TEMP_ATTRIBUTE, tad.getName(), tad.getType().getId(), tad.getColumnName());

		_pseudoObjectIndex = tad.getIndex();
	}

	/**
	 * Gibt den Index des Pseudoobjekt-Tupels zurück. Wird beispielsweise ein Skript mit folgenden Parametern gestartet: (fs, mq) = (fs1, mq1)(fs2, mq2) wird hier
	 * für fs1 und mq1 0 zurückgegeben und für fs2 und mq2 1.
	 *
	 * @return Pseudoobjekt-Index oder -1 falls kein Pseudoobjekt verwendet wurde.
	 */
	public long getPseudoObjectIndex() {
		return _pseudoObjectIndex;
	}

}
