/*
 * Copyright 2019 by Kappich Systemberatung Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.manager.taskmanager;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.pua.prot.manager.ManagerErrorMessage;
import de.bsvrz.pua.prot.manager.datamanager.DataManagerInterface;
import de.bsvrz.pua.prot.processing.Processing;
import de.bsvrz.pua.prot.processing.ProcessingInterface;
import de.bsvrz.pua.prot.sender.PuaSender;
import de.bsvrz.pua.prot.util.ProcessingInformation;
import de.bsvrz.pua.prot.util.ProcessingParameter;
import de.bsvrz.sys.funclib.kappich.annotations.Nullable;
import de.bsvrz.sys.funclib.losb.datk.AtlMeta;
import de.bsvrz.sys.funclib.losb.exceptions.FailureException;
import de.bsvrz.sys.funclib.losb.exceptions.LoggerException;

/**
 * Klasse, die Protokolle erstellt
 * 
 * @author Kappich Systemberatung
 */
public class CreateProtocolTask extends AbstractTask{
	private final ProcessingParameter _pp;

	public CreateProtocolTask(final ClientDavInterface dav, final SystemObject client, final long requestId, final long protocolId, final long jobId, final long startTime, final long initialFlowControl, final ProcessingParameter pp) {
		super(dav, client, requestId, protocolId, jobId, startTime, initialFlowControl);
		_pp = pp;
	}

	public ProcessingParameter getPp() {
		return _pp;
	}

	@Override
	public ThreadElement.Operation getOperation() {
		return ThreadElement.Operation.CREATE_PROTOCOL;
	}

	/**
	 * Führt die Datenaufbereitung durch.
	 *
	 * @return Ergebnis der Datenaufbereitung.
	 *
	 * @throws FailureException Metainformation des Skripts ist korrupt.
	 * @param puaSender        Sender für Antworten
	 * @param dataManager      Datenverwaltung
	 */
	@Nullable
	@Override
	protected ProcessingInterface process(final DataManagerInterface dataManager, ThreadElement threadElement, final PuaSender puaSender) throws FailureException {
		ProcessingInformation pi = dataManager.process(_pp);
		AtlMeta meta = dataManager.getMetaInformation(_pp.getScript());
		if(meta == null) {
			String msg = ManagerErrorMessage.NO_META_INFO + _pp.getScript();
			threadElement.sendError(new FailureException(msg, LoggerException.WARNING));
			return null;
		}
		else {
			return new Processing(puaSender, dataManager, threadElement.getSerializer(), getProtocolId(), _pp, pi, meta, threadElement.getCreator()
					.getConfigAuth(), threadElement.getMaxDelay(), threadElement.getTimeout(), getInitialFlowControl());
		}
	}
}
