/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.util;

import java.util.*;


/**
 * Entspricht {@link de.bsvrz.pua.prot.util.ResultValue}, Änderungen des einmal im Konstruktor gesetzten Wertes werden jedoch verhindert. <br>Bei jedem Versuch,
 * die abgelgeten Werte zu ändern, wird eine {@link java.lang.UnsupportedOperationException} geworfen.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class ImmutableResultValue extends ResultValue {

	private static final long serialVersionUID = 5315196199094595613L;

	/**
	 * @param expressionResult  ExpressionResult
	 * @see ResultValue#ResultValue(ExpressionResult)
	 */
	public ImmutableResultValue(ExpressionResult expressionResult) {
		super(expressionResult);
	}

	/** @return Liefert eine nicht änderbare Liste der Kinder. */
	@Override
    public List<ResultValue> getChildren() {
		return Collections.unmodifiableList(super.getChildren());
	}


	/**
	 * Neue Wertzuweisungen sind nicht erlaubt.
	 *
	 * @param i Länge.
	 *
	 * @throws UnsupportedOperationException Wird immer geworfen.
	 */
	@Override
    public void truncChildren(int i) {
		throw new UnsupportedOperationException("Änderungen sind nicht erlaubt.");
	}


	/**
	 * Änderungen sind nicht erlaubt.
	 *
	 * @param other     Rechter Operand.
	 * @param operation Operation.
	 *
	 * @return <code>this</code>
	 *
	 * @throws UnsupportedOperationException Wird immer geworfen.
	 */
	@Override
    public ResultValue performOperation(ResultValue other, ResultValueOperation operation) {
		throw new UnsupportedOperationException("Änderungen sind nicht erlaubt.");
	}

	/**
	 * Änderungen sind nicht erlaubt. Setzt den Wert des Objekts.
	 *
	 * @param result Wert. throw new UnsupportedOperationException("Änderungen sind nicht erlaubt.");
	 */
	@Override
    public void set(ExpressionResult result) {
		throw new UnsupportedOperationException("Änderungen sind nicht erlaubt.");
	}
}
