/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.util;

import de.bsvrz.sys.funclib.losb.util.Tuple;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;


/**
 * Hilfklasse für die Arbeit mit Zeiträumen. Sortiert und fasst Zeiträume zusammen.
 *
 * @deprecated Stattdessen {@link PeriodSet} benutzen
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
@Deprecated
public class Periods {

	/** Sortierte und zusammengefasste Zeiträume */
	public List<Tuple<Long, Long>> periods;

	/**
	 * Erzeugt das Objekt. Dabei werden die übergebenen Zeiträume sortiert und Überlappungen zusammengefasst. Es werden keine Elemente aus der übergebenen Liste
	 * gelöscht, jedoch kann die Reihenfolge geändert werden. Verwendet {@link #order(List)}.
	 *
	 * @param periods Liste mit Zeiträumen, die angefragt werden sollen. Wichtig: Der erste Tuple.first MUSS kleiner sein, als Tuple.last!
	 */
	public Periods(List<Tuple<Long, Long>> periods) {
		if(!periods.isEmpty()) {
			this.periods = order(periods);
		}
		else {
			this.periods = new ArrayList<>();
		}
	}


	/**
	 * Sortiert die Zeitbereiche aufsteigend und fasst diejenigen Zeiträume zusammen, die sich überschneiden. Es werden keine Elemente aus der übergebenen Liste
	 * gelöscht, jedoch kann die Reihenfolge geändert werden. Lineare Laufzeit.
	 *
	 * @param periods Liste mit Zeiträumen, die angefragt werden sollen. Wichtig: Der erste Tuple.first MUSS kleiner sein, als Tuple.last!
	 *
	 * @return Sortierte und zusammengefasste Zeiträume.
	 */
	@SuppressWarnings("unchecked")
	public static List<Tuple<Long, Long>> order(List<Tuple<Long, Long>> periods) {
		ArrayList<Tuple<Long, Long>> result = new ArrayList<>();

		if(periods != null) {
			Collections.sort(periods);
			/*
			 * Nach dem Sortieren:
			 * Zeitbereiche sind aufsteigend sortiert, d.h. period[i].first <= period[i+1].first (für alle i)
			 */

			result.add(periods.get(0));
			for(int i = 1; i < periods.size(); i++) {
				Tuple<Long, Long> period = periods.get(i);

				Tuple<Long, Long> mergedPeriod = result.get(result.size() - 1);
				/*
				 * Überprüfen, ob Zeitbereich mit der letzten in result abgelegten Periode überlappt.
				 * Warum nur die letzte überprüft wird?
				 * -> Weil (s. Sortierung) der Anfangszeitpunkt von period >= sein MUSS als der von allen
				 * vorhergehenden Zeitbereichen (also auch denen, die in result abgelegt wurden!
				 */
				{
					if(period.first <= mergedPeriod.last)		//Anfang der period liegt innerhalb der mergedPeriod => zusammenfassen!
					{
						if(period.last > mergedPeriod.last)	//Falls der Endzeitpunkt der neuen periode weiter in der Zukunft liegt, mergedPeriod erweitern.
						{
							mergedPeriod.last = period.last;
						}
					}
					else										//Anfang liegt nicht innerhalb mergedP => neuen Zeitpereich anlegen
					{
						result.add(period);
					}
				}
			}
		}
		//return result;
		return result;
	}
}
