/*
 * Copyright 2010 by Kappich Systemberatung Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.client;

/**
 * Listener-Klasse, die über fertigestellte Protokolle informiert wird.
 *
 * @see  de.bsvrz.pua.prot.client.ProtocolListenerEx bietet erweiterte Funktionalität
 * @author Kappich Systemberatung
 * @version $Revision: 8953 $
 */
public interface ProtocolListener {

	/**
	 * Diese Methode kann überschrieben werden und wird jedes mal aufgerufen wenn
	 * ein protokollbezogener Auftrag beendet wurde. Dies betrifft die folgenden Operationen:
	 *
	 * <ul>
	 *     <li>Protokoll erstellen</li>
	 *     <li>Ungelesenes Protokoll abrufen</li>
	 *     <li>Gespeichertes Protokoll abrufen</li>
	 * </ul>
	 *
	 * Der Aufruf dieser Methode ist unabhängig davon, ob die Erstellung/Übertragung
	 * erfolgreich war oder nicht.
	 *
	 * @param jobId Auftrags-ID des beendeten Auftrags. Bei Protokollerstellungsaufträgen identisch mit Protokoll-ID.
	 * @see ProtocolResultStream#getJobId()
	 * @see PuaClient#getJobList(de.bsvrz.pua.prot.util.ProtocolRequestResult)
	 */
	public void protocolFinished(long jobId);
}
