/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.client;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ReceiverRole;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.ConfigurationException;
import de.bsvrz.dav.daf.main.config.DynamicObject;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.losb.datk.PidScript;
import de.bsvrz.sys.funclib.losb.messages.ErrorMessage;

/**
 * Empfänger für skript-bezogene Antworten von PuA. Meldet sich als Empfänger für Nachrichten von PuA an, die auf Anfragen gesendet wurden, die sich auf Skripte
 * beziehen.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
@SuppressWarnings("deprecation")
public class ScriptAnswerReceiver extends AnswerReceiver {
	
	/** Debug Ausgabe */
    private static final Debug _debug = Debug.getLogger();

	/**
	 * Erzeugt den Empfänger. Empfänger meldet sich sofort auf Skript-bezogene Antwortdaten von Pua an.
	 *
	 * @param dav       Verbindung zum Datenverteiler
	 * @param script    Skriptobjekt, auf das sich die Antwort bezieht.
	 * @param receiver  Objekt das die Anfrage, auf die sich die eingehende Antwort bezieht, gesendet hat.
	 * @param requestId Anfrage-Id.
	 * @param timeout   Maximale Wartezeit, in der eine Antwort eingehen muss. <code>0</code> ist die unbegrenzte Wartezeit.
	 *
	 * @throws ConfigurationException Fehler bei der Kommunikation mit der Konfiguration
	 */
	public ScriptAnswerReceiver(ClientDavInterface dav, DynamicObject script, 
			SystemObject receiver, long requestId, long timeout) {
		super(dav, script, PidScript.atgAnswer, PidScript.aspIs, receiver, requestId, timeout);
	}

	@Override
	protected void update(ResultData result) {
		Data data = result.getData();
		try {
			//muss unterschieden wreden!
			Data atlExtra = data.getItem(PidScript.atlExtendedInformation);
			if(receiver.equals(atlExtra.getReferenceValue(PidScript.sender).getSystemObject())
			   && atlExtra.getUnscaledValue(PidScript.requestId).longValue() == requestId) {
				incoming.push(result);
			}
		}
		catch(Exception e) {
			_debug.warning(ErrorMessage.UNEXPECTED_DATA_TYPE + data, e);
		}
	}
}
