/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.processing.onlinebuffer;

/**
 * Klasse die beim Eingang von neuen Daten benachrichtigt wird.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 */
public class NewDataCollector {

	private boolean _hasNewData = false;

	/**
	 * Zeigt an, ob neue Daten eingegangen sind. Das Flag wird dann sofort zurückgesetzt.
	 *
	 * @return <code>true</code> falls neue Daten eingegangen sind.
	 */
	synchronized public boolean hasMoreData() {
		if(_hasNewData) {
			_hasNewData = false;
			return true;
		}
		else {
			return false;
		}
	}

	/** Methode wird aufgerufen, wenn neue Daten vorliegen. */
	synchronized public void newDataAvailable() {
		_hasNewData = true;
		this.notifyAll();
	}

	public boolean hasMore() {
		return _hasNewData;
	}
}
