/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.processing.onlinebuffer;

import de.bsvrz.sys.funclib.losb.datk.ProtocolType;
import de.bsvrz.pua.prot.util.attributes.RealAttributeDescription;
import de.bsvrz.sys.funclib.losb.exceptions.FailureException;

/**
 * Klasse kapselt Onlinewerte für ein Attribut.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class RealOnlineAttribute extends RealOnlineElement {

	/** Attributbeschreibung. */
	RealAttributeDescription _rad;

	/**
	 * Erzeugt das Objekt. Ruft {@link RealOnlineElement#setReceiver(OnlineDataReceiver)} auf.
	 *
	 * @param receiverSet   Objekt das die Anmeldung auf die DAV-Daten durchführt.
	 * @param rad           Attributbeschreibung
	 * @param protocolType ProtocolType
	 * @param isShown       Wird das Element im Spalten-Bereich verwendet? <code>true</code>Element wird im Spalten Bereich verwendet.
	 *
	 * @throws FailureException Fehler bei der Kommunikation mit der Konfiguration.
	 */
	public RealOnlineAttribute(OnlineDataReceiverSet receiverSet, RealAttributeDescription rad, ProtocolType protocolType, boolean isShown)
			throws FailureException {
		super(receiverSet, protocolType, isShown, rad.padData());
		this._rad = rad;
		setReceiver(receiverSet.createReceiver(rad.getReferenceQualification()));
	}

	/** @see RealOnlineElement#executeTake(long) */
	@Override
	public boolean executeTake(long timeout) throws FailureException, InterruptedException {
		boolean result;

		/*
		 * Muss im synchronized block stehen, da this.resultData nach außen NIE den vollständigen Datensatz speichern
		 * soll, den super.take() in resultData schreibt. sondern wirklich nur den Wert des Attributs Eigentlich wäre
		 * ein synchronized this.resultData ausreichend, aber das kann ja null sein
		 */
		synchronized(this) {
			// Daten holen
			result = super.executeTake(timeout);
			if(result) {
				if(_rad.getReference() != null) {
					RealAttributeDescription r = _rad.getReference();
					while(r.getReference() != null) r = r.getReference();
					value.selectData(r);
				}
				else {
					value.selectData(_rad);
				}
			}
		}
		return result;
	}

	/** @see java.lang.Object#toString() */
	@Override
    public String toString() {
		return _rad.toString() + " -> " + ((value == null) ? " - keine Daten - " : "" + value.getData());
	}
}
