/*
 * Copyright 2005-2008 by beck et al. projects GmbH, Munich
 * Copyright 2009 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.bsvrz.pua.prot.
 *
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.bsvrz.pua.prot.processing.util;

import de.bsvrz.pua.prot.client.dataobject.PuADataState;
import de.bsvrz.pua.prot.util.ExpressionResult;
import de.bsvrz.sys.funclib.losb.datk.ProtocolType;
import de.bsvrz.pua.prot.util.ResultValue;
import de.bsvrz.pua.prot.util.attributes.RealAttributeDescription;
import de.bsvrz.pua.prot.util.attributes.RealElement;
import de.bsvrz.pua.prot.util.attributes.TempAttributeDescription;

import java.util.*;

/**
 * Klasse die Online- und Archiv-Werte eines temporären Attributen verwaltet. Temporäre Attribute haben keine Markikerungsinformation. von DataInformations
 * besteht.
 *
 * @author beck et al. projects GmbH
 * @author Martin Hilgers
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class TempAttribut {

	/** Beschreibung des zugehörigen temporären Attributs */
	private TempAttributeDescription _tad;

	/** Markierungsinformation */
	private DataInformation _dataInformation;

	/** Aktueller Wert */
	private BaseDataSet _dataSet = null;

	/** Reales Attribut, dessen zeitstempel vom temporären Attribut verwendet werden soll. */
	private RealAttributeDescription _timeStampOrigin;

	/**
	 * @param tad             Zugeordetes temporäres Attribut.
	 * @param timeStampOrigin Objekt dessen Zeitstempel das temporäre Attribut übernehmen soll.
	 * @param deltaProtocol   Soll ein Änderungsprotokoll erzeugt werden?
	 */
	public TempAttribut(TempAttributeDescription tad, RealAttributeDescription timeStampOrigin, ProtocolType deltaProtocol) {
		this._tad = tad;
		_dataInformation = new DataInformation(deltaProtocol);
		this._timeStampOrigin = timeStampOrigin;
	}

	/**
	 * Liefert den zu verwendenden Wert dieses Elements zurück.
	 *
	 * @param realElements Mapping der realen Elemente zu den ihnen zugeordeten Werten.
	 * @param tempElements Mapping der temporären Attribute zu den ihnen zugeordneten Werten.
	 *
	 * @return Aktueller Wert des temporären Attributs
	 */
	public BaseDataSet getValue(Hashtable<RealElement, BaseDataSet> realElements, Hashtable<TempAttributeDescription, TempAttribut> tempElements) {
		ExpressionResultAndState result = _tad.getValue(realElements, tempElements);

		long dataTime  = BaseDataSet.INVALID_VALUE;
		
		BaseDataSet dataSet = _timeStampOrigin == null ? null : realElements.get(_timeStampOrigin);
		if(dataSet != null) {
			dataTime = dataSet.getDataTimeStamp();
			if(dataTime == Long.MAX_VALUE) dataTime = BaseDataSet.INVALID_VALUE;
		}


		// Wert setzen:
		final PuADataState dataState;
		
		_dataSet = new BaseDataSet(
				new ResultValue(result.getResult()),
				result.getState(),
				_dataInformation,
				dataTime,
				BaseDataSet.INVALID_VALUE,
				BaseDataSet.INVALID_VALUE,
				BaseDataSet.INVALID_VALUE,
				dataSet == null ? BaseDataSet.INVALID_VALUE : dataSet.getDataIndex(),
				false
		);

		return _dataSet;
	}

	/**
	 * Liefert den Ursprung des Zeitstempel des temporären Attributs.
	 *
	 * @return Objekt, dessen Zeitstempel dem temporären Attribut zugeordnet wird.
	 */
	public RealAttributeDescription getTimeStampOrigin() {
		return _timeStampOrigin;
	}
}
